Actions, Resources, and Condition Keys for AWS IoT 1-Click - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IoT 1-Click.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for AWS IoT 1-Click

AWS IoT 1-Click (service prefix: `iot1click`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS IoT 1-Click
- Resources Defined by AWS IoT 1-Click
- Condition Keys for AWS IoT 1-Click

## Actions Defined by AWS IoT 1-Click

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AssociateDeviceWithPlacement | Associate a device to a placement | Write | project* |  |
ClaimDevicesByClaimCode | Claim a batch of devices with a claim code. | Read |  |  |
CreatePlacement | Create a new placement in a project | Write | project* |  |
CreateProject | Create a new project | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeletePlacement | Delete a placement from a project | Write | project* |  |
DeleteProject | Delete a project | Write | project* |  |
DescribeDevice | Describe a device | Read | device* |  |
DescribePlacement | Describe a placement | Read | project* |  |
DescribeProject | Describe a project | Read | project* |  |
DisassociateDeviceFromPlacement | Disassociate a device from a placement | Write | project* |  |
FinalizeDeviceClaim | Finalize a device claim | Read | device* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
GetDeviceMethods | Get available methods of a device | Read | device* |  |
GetDevicesInPlacement | Get devices associated to a placement | Read | project* |  |
InitiateDeviceClaim | Initialize a device claim | Read | device* |  |
InvokeDeviceMethod | Invoke a device method | Write | device* |  |
ListDeviceEvents | List past events published by a device | Read | device* |  |
ListDevices | List all devices | List |  |  |
ListPlacements | List placements in a project | Read | project* |  |
ListProjects | List all projects | List |  |  |
ListTagsForResource | Lists the tags (metadata) which you have assigned to the resource. | List | device |  |
project |  |
TagResource | Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource. | Write | device |  |
project |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UnclaimDevice | Unclaim a device | Read | device* |  |
UntagResource | Removes the given tags (metadata) from the resource. | Write | device |  |
project |  |
| aws:TagKeys |
UpdateDeviceState | Update device state | Write | device* |  |
UpdatePlacement | Update a placement | Write | project* |  |
UpdateProject | Update a project | Write | project* |  |

## Resources Defined by AWS IoT 1-Click

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
device | `arn:${Partition}:iot1click:${Region}:${Account}:devices/${DeviceId}` | aws:ResourceTag/${TagKey}
project | `arn:${Partition}:iot1click:${Region}:${Account}:projects/${ProjectName}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS IoT 1-Click

AWS IoT 1-Click defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | A tag key that is present in the request that the user makes to IoT 1-Click. | String
aws:ResourceTag/${TagKey} | The preface string for a tag key and value pair attached to an IoT 1-Click resource. | String
aws:TagKeys | The list of all the tag key names associated with the IoT 1-Click resource in the request. | String

On this page:

- Actions Defined by AWS IoT 1-Click
- Resources Defined by AWS IoT 1-Click
- Condition Keys for AWS IoT 1-Click

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more